@@ -221,7 +221,7 @@ sub scan {
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
-        $e->{'agent'} ||= __PACKAGE__->smtpagent;
+        $e->{'agent'}   = __PACKAGE__->smtpagent;
         $e->{'rhost'} ||= $connheader->{'rhost'};
 
         if( scalar @{ $mhead->{'received'} } ) {
