@@ -151,9 +151,9 @@ sub scan {
         $e->{'diagnosis'} =~ s{\\n}{ }g;
         $e->{'diagnosis'} =  Sisimai::String->sweep( $e->{'diagnosis'} );
 
-        $e->{'status'}  =  Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
-        $e->{'spec'}  ||= 'SMTP';
-        $e->{'agent'} ||= __PACKAGE__->smtpagent;
+        $e->{'status'} =  Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'spec'} ||= 'SMTP';
+        $e->{'agent'}  = __PACKAGE__->smtpagent;
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
