@@ -275,7 +275,7 @@ sub scan {
             $e->{'status'} = $f if length $f;
         }
         $e->{'spec'}      = '' unless $e->{'spec'} =~ m/\A(?:SMTP|X-UNIX)\z/;
-        $e->{'agent'}   ||= __PACKAGE__->smtpagent;
+        $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'command'} ||= $commandtxt || '';
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
