@@ -9,12 +9,13 @@ sub match {
     my $argvs = shift // return undef;
     my $regex = qr{(?:
          DNS[ ]records[ ]for[ ]the[ ]destination[ ]computer[ ]could[ ]not[ ]be[ ]found
+        |Hop[ ]count[ ]exceeded[ ]-[ ]possible[ ]mail[ ]loop
         |host[ ]is[ ]unreachable
         |mail[ ]forwarding[ ]loop[ ]for[ ]
         |malformed[ ]name[ ]server[ ]reply
         |maximum[ ]forwarding[ ]loop[ ]count[ ]exceeded
         |message[ ]looping
-        |name[ ]service[ ]error[ ]for
+        |name[ ]service[ ]error
         |too[ ]many[ ]hops
         |unrouteable[ ]mail[ ]domain
         )
