@@ -56,6 +56,7 @@ sub list {
             MTA/qmail.pm
             MTA/Sendmail.pm
             MTA/SurfControl.pm
+            MTA/UserDefined.pm
             MTA/V5sendmail.pm
             MTA/X1.pm
             MTA/X2.pm
@@ -87,6 +88,7 @@ sub list {
         RFC2606.pm
         RFC3463.pm
         RFC3464.pm
+        RFC3834.pm
         RFC5321.pm
         RFC5322.pm
         Rhost.pm
